
# MarkItDown

MarkItDown is a Drupal 10 module that converts PDF, DOCX, XLSX, and other file formats to Markdown. This module uses the open-source tool [markitdown](https://github.com/microsoft/markitdown) developed by Microsoft for file conversion.
This module Will automaticaly trans the uploaded attachement file to markdown and put it into body field.

## Features

- Supports converting PDF, DOCX, XLSX, PPT, and other file formats to Markdown.
- Provides two output modes: text mode and file mode.
- Offers a "Convert to Markdown" operation on the file details page.
- Configurable markitdown tool path.

## Dependencies

This module depends on the following tool:

- **markitdown**: The file conversion tool developed by Microsoft.

### Installing markitdown

To install markitdown using pip:

```bash
pip install 'markitdown[all]~=0.1.0a1'
```

Alternatively, you can install from the source:

```bash
git clone git@github.com:microsoft/markitdown.git
cd markitdown
pip install -e packages/markitdown[all]
```

Ensure that the markitdown command is available in your system's PATH, or specify the full path in the module's settings.

## Installation

1. Place the module in the `/web/modules/viz_modules/` directory.
2. Enable the module in the Drupal administration interface.
3. Visit `/admin/config/content/markitdown` to configure module settings.

## Usage

### Basic Usage

1. Upload a file to Drupal.
2. Visit the file details page.
3. Click the "Convert to Markdown" button.
4. By default, the conversion result will be displayed directly in the browser.

### Output Modes

The module supports two output modes:

1. **Text Mode**: Directly returns the converted Markdown content.
   - Use the URL parameter: `?output_mode=text` (default).

2. **File Mode**: Saves the conversion result to a specified path.
   - Use the URL parameter: `?output_mode=file&output_path=/path/to/save/file.md`.

### API Usage

You can also use the MarkdownConverter service in your own code:

```php
// Get the service
$converter = \Drupal::service('markitdown.converter');

// Text Mode - Returns content
$markdown = $converter->convertToMarkdown('/path/to/file.pdf', [
  'output_mode' => 'text',
]);

// File Mode - Save to file
$result = $converter->convertToMarkdown('/path/to/file.pdf', [
  'output_mode' => 'file',
  'output_path' => '/path/to/save/output.md',
]);
```

## Permissions

- **administer markitdown**: Allows users to configure module settings.
- **convert files to markdown**: Allows users to convert files to Markdown.

## Troubleshooting

If the conversion fails, check:

1. Whether the markitdown tool is correctly installed.
2. Whether the markitdown path is correctly configured in the module settings.
3. Whether Drupal has sufficient permissions to execute the markitdown command.
4. Check error messages in the Drupal logs.


# MarkItDown

MarkItDown是一个Drupal 10模块，用于将PDF、DOCX、XLSX等文件转换为Markdown格式。该模块使用Microsoft开发的开源工具 [markitdown](https://github.com/microsoft/markitdown) 进行文件转换。

## 功能

- 支持将PDF、DOCX、XLSX、PPT等多种文件格式转换为Markdown
- 提供两种输出模式：文本模式和文件模式
- 提供文件详情页面上的"转换为Markdown"操作
- 可配置的markitdown工具路径

## 依赖

此模块依赖以下工具：

- **markitdown**: Microsoft开发的文件转换工具

### 安装markitdown

使用pip安装markitdown：

```bash
pip install 'markitdown[all]~=0.1.0a1'
```

或者从源代码安装：

```bash
git clone git@github.com:microsoft/markitdown.git
cd markitdown
pip install -e packages/markitdown[all]
```

确保markitdown命令在系统PATH中可用，或在模块设置中指定完整路径。

## 安装

1. 将模块放置在`/web/modules/viz_modules/`目录下
2. 在Drupal管理界面启用模块
3. 访问`/admin/config/content/markitdown`配置模块设置

## 使用方法

### 基本使用

1. 上传文件到Drupal
2. 访问文件详情页面
3. 点击"转换为Markdown"按钮
4. 默认情况下，转换结果将直接显示在浏览器中

### 输出模式

模块支持两种输出模式：

1. **文本模式**：直接返回转换后的Markdown文本内容
   - 使用URL参数：`?output_mode=text`（默认）

2. **文件模式**：将转换结果保存到指定路径
   - 使用URL参数：`?output_mode=file&output_path=/path/to/save/file.md`

### API使用

您也可以在自己的代码中使用MarkdownConverter服务：

```php
// 获取服务
$converter = \Drupal::service('markitdown.converter');

// 文本模式 - 返回内容
$markdown = $converter->convertToMarkdown('/path/to/file.pdf', [
  'output_mode' => 'text',
]);

// 文件模式 - 保存到文件
$result = $converter->convertToMarkdown('/path/to/file.pdf', [
  'output_mode' => 'file',
  'output_path' => '/path/to/save/output.md',
]);
```

## 权限

- **administer markitdown**: 允许用户配置模块设置
- **convert files to markdown**: 允许用户将文件转换为Markdown

## 故障排除

如果转换失败，请检查：

1. markitdown工具是否正确安装
2. 在模块设置中是否正确配置了markitdown路径
3. Drupal有足够的权限执行markitdown命令
4. 检查Drupal日志中的错误信息
